@@ -20,7 +20,10 @@ class ItemKey:
         return boto3.dynamodb.conditions.Key(self.name).eq(self.value)
 
     def as_dynamodb_key(self):
-        return {*{self.name: self.value}, *(self.secondary.as_dynamodb_key() if self.secondary else {})}
+        return {
+            self.name: self.value,
+            **(self.secondary.as_dynamodb_key() if self.secondary else {}),
+        }
 
 
 class InternalError(Exception):
